@@ -30,6 +30,7 @@ class MockTopic(Topic):
 
         if not self.exists():
             MESSAGES[get_service_id(self.path)] = []
+            self._created = True
 
     def delete(self):
         """Delete the topic from the global messages dictionary.
@@ -59,7 +60,7 @@ class MockSubscription(Subscription):
         :param bool allow_existing:
         :return None:
         """
-        pass
+        self._created = True
 
     def delete(self):
         """Do nothing.
@@ -91,6 +92,9 @@ class MockFuture:
 class MockPublisher:
     """A mock publisher that puts messages in a global dictionary instead of Google Pub/Sub."""
 
+    def __init__(self, *args, **kwargs):
+        pass
+
     def publish(self, topic, data, retry=None, **attributes):
         """Put the data and attributes into a MockMessage and add it to the global messages dictionary before returning
         a MockFuture.
