@@ -6,9 +6,8 @@ import json
 import logging
 import uuid
 
-import packaging.version
+import google.api_core.exceptions
 import pkg_resources
-from google import auth
 from google.api_core import retry
 from google.cloud import pubsub_v1
 
@@ -16,6 +15,7 @@ import octue.exceptions
 from octue.cloud.pub_sub import Subscription, Topic
 from octue.cloud.pub_sub.logging import GooglePubSubHandler
 from octue.cloud.pub_sub.message_handler import OrderedMessageHandler
+from octue.compatibility import warn_if_incompatible
 from octue.mixins import CoolNameable
 from octue.utils.encoders import OctueJSONEncoder
 from octue.utils.exceptions import convert_exception_to_primitives
@@ -65,12 +65,10 @@ class Service(CoolNameable):
 
         self.backend = backend
         self.run_function = run_function
-        self._raw_local_sdk_version = pkg_resources.get_distribution("octue").version
-        self._parsed_local_sdk_version = packaging.version.parse(self._raw_local_sdk_version)
+        self._local_sdk_version = pkg_resources.get_distribution("octue").version
         self._record_sent_messages = False
         self._sent_messages = []
         self._publisher = None
-        self._credentials = None
         super().__init__(*args, **kwargs)
 
     def __repr__(self):
@@ -85,67 +83,59 @@ class Service(CoolNameable):
         :return google.cloud.pubsub_v1.PublisherClient:
         """
         if not self._publisher:
-            self._publisher = pubsub_v1.PublisherClient(credentials=self.credentials, batch_settings=BATCH_SETTINGS)
+            self._publisher = pubsub_v1.PublisherClient(batch_settings=BATCH_SETTINGS)
 
         return self._publisher
 
-    @property
-    def credentials(self):
-        """Get or instantiate the Google Cloud credentials for the service. No credentials are instantiated until this
-        property is called for the first time. This allows checking for the `GOOGLE_APPLICATION_CREDENTIALS` environment
-        variable to be put off until it's needed.
-
-        :return google.auth.credentials.Credentials:
-        """
-        if not self._credentials:
-            self._credentials = auth.default()[0]
-
-        return self._credentials
-
-    def serve(self, timeout=None, delete_topic_and_subscription_on_exit=False):
+    def serve(self, timeout=None, delete_topic_and_subscription_on_exit=False, allow_existing=False):
         """Start the service as a child, waiting to accept questions from any other Octue service using Google Pub/Sub
         on the same Google Cloud project. Questions are accepted, processed, and answered asynchronously.
 
         :param float|None timeout: time in seconds after which to shut down the child
         :param bool delete_topic_and_subscription_on_exit: if `True`, delete the child's topic and subscription on exiting serving mode
+        :param bool allow_existing: if `True`, allow starting a service for which the topic and/or subscription already exists (indicating an existing service) - this connects this service to the existing service's topic and subscription
         :return None:
         """
         logger.info("Starting %r.", self)
 
-        topic = Topic(name=self.id, namespace=OCTUE_NAMESPACE, service=self)
-        subscriber = pubsub_v1.SubscriberClient(credentials=self.credentials)
+        topic = Topic(name=self.id, project_name=self.backend.project_name, namespace=OCTUE_NAMESPACE)
 
         subscription = Subscription(
             name=self.id,
             topic=topic,
             namespace=OCTUE_NAMESPACE,
             project_name=self.backend.project_name,
-            subscriber=subscriber,
             expiration_time=None,
         )
 
-        try:
-            topic.create(allow_existing=True)
-            subscription.create(allow_existing=True)
+        subscriber = pubsub_v1.SubscriberClient()
 
+        try:
+            topic.create(allow_existing=allow_existing)
+            subscription.create(allow_existing=allow_existing)
             future = subscriber.subscribe(subscription=subscription.path, callback=self.answer)
-            logger.debug("%r is waiting for questions.", self)
+
+            logger.info(
+                "You can now ask this service questions at %r using the `octue.resources.Child` class.",
+                self.id,
+            )
 
             try:
                 future.result(timeout=timeout)
             except (TimeoutError, concurrent.futures.TimeoutError, KeyboardInterrupt):
                 future.cancel()
 
+        except google.api_core.exceptions.AlreadyExists:
+            raise octue.exceptions.ServiceAlreadyExists(f"A service with the ID {self.id!r} already exists.")
+
         finally:
             if delete_topic_and_subscription_on_exit:
                 try:
-                    if subscription.exists():
+                    if subscription.creation_triggered_locally:
                         subscription.delete()
-                        logger.info("Subscription deleted.")
 
-                    if topic.exists():
+                    if topic.creation_triggered_locally:
                         topic.delete()
-                        logger.info("Topic deleted.")
 
                 except Exception:
                     logger.error("Deletion of topic and/or subscription %r failed.", topic.name)
@@ -199,25 +189,6 @@ class Service(CoolNameable):
             else:
                 analysis_log_handler = None
 
-            if parent_sdk_version:
-                if (
-                    self._parsed_local_sdk_version.major != parent_sdk_version.major
-                    or self._parsed_local_sdk_version.minor != parent_sdk_version.minor
-                ):
-                    logger.warning(
-                        "The parent's Octue SDK version %s may not be compatible with the local Octue SDK version %s. "
-                        "Update them both to the latest version (or at least a version with the same major and minor "
-                        "version numbers) if possible.",
-                        parent_sdk_version,
-                        self._parsed_local_sdk_version,
-                    )
-
-            else:
-                logger.warning(
-                    "The parent couldn't be checked for compatibility with this service because it didn't send its Octue "
-                    "SDK version with its question. Please update it to the latest Octue SDK version."
-                )
-
             analysis = self.run_function(
                 analysis_id=question_uuid,
                 input_values=data["input_values"],
@@ -249,6 +220,7 @@ class Service(CoolNameable):
 
         except BaseException as error:  # noqa
             heartbeater.cancel()
+            warn_if_incompatible(child_sdk_version=self._local_sdk_version, parent_sdk_version=parent_sdk_version)
             self.send_exception(topic, timeout)
             raise error
 
@@ -289,7 +261,7 @@ class Service(CoolNameable):
 
         unlinted_service_id = service_id
         service_id = self._clean_service_id(service_id)
-        question_topic = Topic(name=service_id, namespace=OCTUE_NAMESPACE, service=self)
+        question_topic = Topic(name=service_id, project_name=self.backend.project_name, namespace=OCTUE_NAMESPACE)
 
         if not question_topic.exists(timeout=timeout):
             raise octue.exceptions.ServiceNotFound(f"Service with ID {unlinted_service_id!r} cannot be found.")
@@ -304,10 +276,9 @@ class Service(CoolNameable):
             topic=answer_topic,
             namespace=OCTUE_NAMESPACE,
             project_name=self.backend.project_name,
-            subscriber=pubsub_v1.SubscriberClient(credentials=self.credentials),
             push_endpoint=push_endpoint,
         )
-        answer_subscription.create(allow_existing=True)
+        answer_subscription.create(allow_existing=False)
 
         serialised_input_manifest = None
 
@@ -355,11 +326,9 @@ class Service(CoolNameable):
                 f"Cannot pull from {subscription.path!r} subscription as it is a push subscription."
             )
 
-        subscriber = pubsub_v1.SubscriberClient(credentials=self.credentials)
-
         message_handler = OrderedMessageHandler(
-            subscriber=subscriber,
             subscription=subscription,
+            receiving_service=self,
             handle_monitor_message=handle_monitor_message,
             service_name=service_name,
             record_messages_to=record_messages_to,
@@ -373,7 +342,6 @@ class Service(CoolNameable):
             )
         finally:
             subscription.delete()
-            subscriber.close()
 
     def instantiate_answer_topic(self, question_uuid, service_id=None):
         """Instantiate the answer topic for the given question UUID and child service ID.
@@ -384,8 +352,8 @@ class Service(CoolNameable):
         """
         return Topic(
             name=".".join((service_id or self.id, ANSWERS_NAMESPACE, question_uuid)),
+            project_name=self.backend.project_name,
             namespace=OCTUE_NAMESPACE,
-            service=self,
         )
 
     def send_exception(self, topic, timeout=30):
@@ -427,7 +395,7 @@ class Service(CoolNameable):
         :param attributes: key-value pairs to attach to the message - the values must be strings or bytes
         :return None:
         """
-        attributes["octue_sdk_version"] = self._raw_local_sdk_version
+        attributes["octue_sdk_version"] = self._local_sdk_version
         converted_attributes = {}
 
         for key, value in attributes.items():
@@ -509,7 +477,7 @@ class Service(CoolNameable):
         """Parse a question in the Google Cloud Pub/Sub or Google Cloud Run format.
 
         :param dict|Message question:
-        :return (dict, str, bool, packaging.version.Version|None, bool):
+        :return (dict, str, bool, str|None, bool):
         """
         try:
             # Parse question directly from Pub/Sub or Dataflow.
@@ -541,7 +509,4 @@ class Service(CoolNameable):
         except AttributeError:
             allow_save_diagnostics_data_on_crash = False
 
-        if parent_sdk_version:
-            parent_sdk_version = packaging.version.parse(parent_sdk_version)
-
         return data, question_uuid, forward_logs, parent_sdk_version, allow_save_diagnostics_data_on_crash
