@@ -1,3 +1,4 @@
+import concurrent.futures
 import copy
 
 from octue.cloud.pub_sub.service import Service
@@ -43,6 +44,7 @@ class Child:
         subscribe_to_logs=True,
         allow_local_files=False,
         handle_monitor_message=None,
+        record_messages_to=None,
         allow_save_diagnostics_data_on_crash=True,
         question_uuid=None,
         timeout=86400,
@@ -56,6 +58,7 @@ class Child:
         :param bool subscribe_to_logs: if `True`, subscribe to logs from the child and handle them with the local log handlers
         :param bool allow_local_files: if `True`, allow the input manifest to contain references to local files - this should only be set to `True` if the child will have access to these local files
         :param callable|None handle_monitor_message: a function to handle monitor messages (e.g. send them to an endpoint for plotting or displaying) - this function should take a single JSON-compatible python primitive as an argument (note that this could be an array or object)
+        :param str|None record_messages_to: if given a path to a JSON file, messages received in response to the question are saved to it
         :param bool allow_save_diagnostics_data_on_crash: if `True`, allow the input values and manifest (and its datasets) to be saved by the child if it fails while processing them
         :param str|None question_uuid: the UUID to use for the question if a specific one is needed; a UUID is generated if not
         :param float timeout: time in seconds to wait for an answer before raising a timeout error
@@ -76,6 +79,21 @@ class Child:
         return self._service.wait_for_answer(
             subscription=subscription,
             handle_monitor_message=handle_monitor_message,
+            record_messages_to=record_messages_to,
             service_name=self.id,
             timeout=timeout,
         )
+
+    def ask_multiple(self, *questions):
+        """Ask the child multiple questions in parallel and wait for the answers. Each question should be provided as a
+        dictionary of `Child.ask` keyword arguments.
+
+        :param questions: any number of questions provided as dictionaries of arguments to the `Child.ask` method
+        :return list: the answers to the questions in the same order as the questions
+        """
+
+        def ask(question):
+            return self.ask(**question)
+
+        with concurrent.futures.ThreadPoolExecutor() as executor:
+            return list(executor.map(ask, questions))
